import os
from datetime import date, timedelta

class Configuration:

    # Working directory
    workdir = os.path.dirname(__file__)
    if (len(workdir) > 0):
        workdir += os.sep
    workdir=workdir.replace('\\','/')
    # Feel free to replace workdir with a full path to the folder with the .json files. Ensure ending it with a slash ('/').
    # workdir = 'D:/Caboverde/'

    # Download configuration
    download = True # False -> do not attempt downloading (again) the sentinel-2 zipfiles (avoid over-contacting the eumetsat service; use it only when needed).
    offlineTrigger = False # True -> request esa to put images online (esa needs a while, and one can only request 20 images per day); False ->leave offline
    #starttime = date(2020, 7, 25)
    starttime = date.today() - timedelta(7) # example: past week
    endtime = date.today()
    cloudcovermax = 100 # 100 = fetch all images, regardless of cloudcover (we accept 100% cloudcover)

    # Processing configuration
    process = True # False -> do not process (when we want to focus on downloading, til e.g. all offline images are also available, in order to get mosaics without missing tiles)
    bands = ['TCI_10m'] #examples , 'B03_10m', 'B07_20m', 'B11_20m', 'B12_20m', 'SCL_20m'; all S2 bands can be requested in one round
    stretched = False # only has effect in band TCI; True -> Bands are scaled to 1% cutoff; False -> Bands are not scaled
    ilwisCC = True # only has effect in band TCI; True -> an ILWIS Color Composite is created; False -> a multiband raster is created
    autoMosaic = True # True -> mosaic will be created; False -> the individual tiles will be exported separately

